@@ -5,7 +5,6 @@
 Webware for Python
 
 See the CGIWrapper.html documentation for more information.
-
 """
 
 # We first record the starting time, in case we're being run as a CGI script.
@@ -13,7 +12,10 @@ from time import time, localtime, asctime
 serverStartTime = time()
 
 # Some imports
-import cgi, os, sys, traceback
+import cgi
+import os
+import sys
+import traceback
 from random import randint
 try:
     from cStringIO import StringIO
@@ -43,7 +45,6 @@ class CGIWrapper(object):
     for both the script and website developer and the administrator.
 
     See the CGIWrapper.html documentation for full information.
-
     """
 
 
@@ -60,7 +61,6 @@ class CGIWrapper(object):
 
         Subclasses could override to customize the values
         or where they're taken from.
-
         """
         return dict(
             ScriptsHomeDir = 'Examples',
@@ -107,7 +107,6 @@ class CGIWrapper(object):
         This are overrides found in the optional configuration file,
         or {} if there is no such file. The config filename is taken
         from configFilename().
-
         """
         try:
             f = open(self.configFilename())
@@ -125,7 +124,6 @@ class CGIWrapper(object):
 
         This is a combination of defaultConfig() and userConfig().
         This method does no caching.
-
         """
         config = self.defaultConfig()
         config.update(self.userConfig())
@@ -162,7 +160,6 @@ class CGIWrapper(object):
         """Check that given environment variable names exist.
 
         If they don't, a basic HTML error message is printed and we exit.
-
         """
         badNames = [name for name in names if name not in self._environ]
         if badNames:
@@ -180,7 +177,6 @@ class CGIWrapper(object):
         Scripts that start with an underscore are special -- they run
         out of the same directory as the CGI Wrapper and are typically
         CGI Wrapper support scripts.
-
         """
         # remove the CGI Wrapper's filename part
         pathname = os.path.split(self._environ['SCRIPT_FILENAME'])[0]
@@ -219,7 +215,6 @@ class CGIWrapper(object):
         """Write an entry to the script log file.
 
         Uses settings ScriptLogFilename and ScriptLogColumns.
-
         """
         filename = self.setting('ScriptLogFilename')
         if os.path.exists(filename):
@@ -251,7 +246,6 @@ class CGIWrapper(object):
         Invoked by self when an exception occurs in the target script.
         <code>excInfo</code> is a sys.exc_info()-style tuple of information
         about the exception.
-
         """
         # Note the duration of the script and time of the exception
         self._scriptEndTime = time()
@@ -277,7 +271,6 @@ class CGIWrapper(object):
         Logs the time, script name and traceback to the console
         (typically stderr). This usually results in the information
         appearing in the web server's error log. Used by handleException().
-
         """
         # stderr logging
         stderr.write('[%s] [error] CGI Wrapper:'
@@ -291,7 +284,6 @@ class CGIWrapper(object):
         Used by handleException() to clear out the current CGI output results
         in preparation of delivering an HTML error message page.
         Currently resets headers and deletes cookies, if present.
-
         """
         # Set headers to basic text/html. We don't want stray headers
         # from a script that failed.
@@ -305,7 +297,6 @@ class CGIWrapper(object):
 
         There could be more options in the future, so using named arguments
         (e.g. showDebugInfo=False) is recommended. Invoked by handleException().
-
         """
         html = ['''%s
 <html>
@@ -324,7 +315,6 @@ class CGIWrapper(object):
         """Return an HTML page with debugging info on the current exception.
 
         Used by handleException().
-
         """
         html = ['''
 %s<p><i>%s</i></p>
@@ -348,7 +338,6 @@ class CGIWrapper(object):
         """Save the given HTML error page for later viewing by the developer.
 
         Returns the filename used. Invoked by handleException().
-
         """
         dir = self.setting('ErrorMessagesDir')
         if not os.path.exists(dir):
@@ -370,7 +359,6 @@ class CGIWrapper(object):
         """Construct a filename for an HTML error page.
 
         This filename does not include the 'ErrorMessagesDir' setting.
-
         """
         # Note: Using the timestamp and a random number is a poor technique
         # for filename uniqueness, but it is fast and good enough in practice.
@@ -385,12 +373,11 @@ class CGIWrapper(object):
         exception-name, exception-data, error report filename)
         to the errors file (typically 'Errors.csv') in CSV format.
         Invoked by handleException().
-
         """
         if not excInfo:
             excInfo = sys.exc_info()
         err, msg = excInfo[:2]
-        if isinstance(err, basestring): # string exception
+        if isinstance(err, basestring):  # string exception
             err, msg = '', str(msg or err)
         else:
             err, msg = err.__name__, str(msg)
@@ -545,7 +532,6 @@ class CGIWrapper(object):
 
         This is used for the output that came from the script being served,
         or from our own error reporting.
-
         """
         # Compile the headers & cookies
         headers = StringIO()
@@ -575,6 +561,7 @@ def docType():
         ' "-//W3C//DTD HTML 4.01 Transitional//EN"'
         ' "http://www.w3.org/TR/html4/loose.dtd">')
 
+
 def htTitle(name):
     """Return an HTML section title."""
     return ('<h2 style="color:white;background-color:#993333;'
@@ -582,6 +569,7 @@ def htTitle(name):
         'font-family:Tahoma,Verdana,Arial,Helvetica,sans-serif"'
         ' align="center">%s</h2>\n' % name)
 
+
 def htDictionary(d, addSpace=None):
     """Returns an HTML table where each row is a key-value pair."""
     if not d:
@@ -597,6 +585,7 @@ def htDictionary(d, addSpace=None):
     html.append('</table>')
     return '\n'.join(html)
 
+
 def htTable(listOfDicts, keys=None):
     """Return an HTML table for a list of dictionaries.
 
@@ -610,7 +599,6 @@ def htTable(listOfDicts, keys=None):
 
     Deficiencies: There's no way to influence the formatting or to
     use column titles that are different from the keys.
-
     """
     if not listOfDicts:
         return ''
@@ -629,6 +617,7 @@ def htTable(listOfDicts, keys=None):
     html.append('</table>')
     return '\n'.join(html)
 
+
 def osIdTable():
     """Get all OS id information.
 
@@ -636,7 +625,6 @@ def osIdTable():
     as uid, gid, etc., all obtained from the os module.
 
     Dictionary keys are 'name' and 'value'.
-
     """
     funcs = ['getegid', 'geteuid', 'getgid', 'getpgrp',
         'getpid', 'getppid', 'getuid']
