@@ -34,23 +34,20 @@ By default, title='Contents', depth=6, skip=0 and classname='contents'.
 DOWNLOAD
 
 This script is part of Webware for Python.
-You can download the latest version from the SVN repository
-(http://svn.w4py.org/Webware/trunk/DocSupport/autotoc.py).
+You can download the latest version from the GitHub repository
+(https://github.com/Cito/w4py/blob/master/DocSupport/autotoc.py).
 
 
 COPYRIGHT
 
 Copyright (c) 2005 by Christoph Zwerschke.
 Licensed under the Open Software License version 2.1.
-
 """
 
+import sys
+import re
+
 __version__ = '0.2'
-__revision__ = "$Revision: 7982 $"
-__date__ = "$Date: 2009-06-27 19:00:35 +0200 (Sa, 27 Jun 2009) $"
-
-
-import sys, re
 
 
 class ToC(object):
@@ -116,14 +113,12 @@ class AutoToC(object):
     """Main class for automatic creation of table(s) of contents.
 
     Provides only one method process().
-
     """
 
     def __init__(self, depth=6):
         """Initialize the AutoToC processor.
 
         You may define a maximum depth here already.
-
         """
         if depth not in range(1, 7):
             depth = 6
@@ -141,12 +136,11 @@ class AutoToC(object):
         """Create table(s) of contents and put them where indicated.
 
         Input and output are strings.
-
         """
         # Read in all contents directives:
         tocs_found = self._toc_directive.findall(input)
         if not tocs_found:
-            return input # no table of contents directive in the input
+            return input  # no table of contents directive in the input
         maxdepth = 0
         tocs = []
         group = self._toc_directive.groupindex
@@ -162,7 +156,7 @@ class AutoToC(object):
         # Read in all headings:
         headings_found = self._heading_pattern.findall(input)
         if not headings_found:
-            return input # no headings in the input
+            return input  # no headings in the input
         mindepth = 6
         headings = []
         names = {}
@@ -186,9 +180,9 @@ class AutoToC(object):
             name = heading_found[group['name'] - 1]
             if name:
                 name_created = False
-            else: # no name given
-                name = self._make_name(title) # create one
-                if name in names: # make sure it is unique
+            else:  # no name given
+                name = self._make_name(title)  # create one
+                if name in names:  # make sure it is unique
                     n = names[name] + 1
                     while '%s-%d' % (name, n) in names:
                         n += 1
