@@ -1,13 +1,13 @@
 #!/usr/bin/env python
 
-# Author: David Goodger <goodger@python.org>
-# Copyright: This module has been placed in the public domain.
-
 """Generate .html from all the .txt files in a directory.
 
 Ordinary .txt files are understood to be standalone reStructuredText.
 Files named ``pep-*.txt`` are interpreted as reStructuredText PEPs.
 
+Author: David Goodger <goodger@python.org>
+
+Copyright: This module has been placed in the public domain.
 """
 
 # Once PySource is here, build .html from .py as well.
@@ -24,7 +24,6 @@ except Exception:
 import sys
 import os
 import os.path
-import copy
 from fnmatch import fnmatch
 
 import docutils
@@ -63,10 +62,10 @@ class SettingsSpec(docutils.SettingsSpec):
            'validator': frontend.validate_colon_separated_string_list}),
          ('Recursively ignore files or directories matching any of the given '
           'wildcard (shell globbing) patterns (separated by colons).  '
-          'Default: ".svn:CVS"',
+          'Default: ".git:.hg:.svn"',
           ['--ignore'],
           {'metavar': '<patterns>', 'action': 'append',
-           'default': ['.svn', 'CVS'],
+           'default': ['.git', '.hg', '.svn'],
            'validator': frontend.validate_colon_separated_string_list}),
          ('Work silently (no progress messages).  Independent of "--quiet".',
           ['--silent'],
@@ -127,7 +126,6 @@ class Builder(object):
         its own configuration defaults, which must be kept separate from those
         of the other publishers.  Setting defaults are combined with the
         config file settings and command-line options by `self.get_settings()`.
-
         """
         for name, publisher in self.publishers.items():
             option_parser = OptionParser(
@@ -149,7 +147,6 @@ class Builder(object):
         Copy the setting defaults, overlay the startup config file settings,
         then the local config file settings, then the command-line options.
         Assumes the current directory has been set.
-
         """
         publisher = self.publishers[publisher_name]
         settings = frontend.Values(publisher.setting_defaults.__dict__)
@@ -195,7 +192,7 @@ class Builder(object):
         for name in names:
             if name.endswith('.txt'):
                 if self.process_txt(directory, name):
-                    break # prune
+                    break  # prune
         if not recurse:
             del names[:]
 
