@@ -24,14 +24,13 @@ class UserManagerToFile(UserManager):
 
     The default user directory is the current working directory,
     but relying on the current directory is often a bad practice.
-
     """
 
 
     ## Init ##
 
     def __init__(self, userClass=None):
-        super(UserManagerToFile, self).__init__(userClass=None)
+        UserManager.__init__(self, userClass=None)
         self.setEncoderDecoder(dump, load)
         self.setUserDir(os.getcwd())
         self.initNextSerialNum()
@@ -56,7 +55,6 @@ class UserManagerToFile(UserManager):
         """Set the directory where user information is stored.
 
         You should strongly consider invoking initNextSerialNum() afterwards.
-
         """
         self._userDir = userDir
 
@@ -65,7 +63,6 @@ class UserManagerToFile(UserManager):
 
         If there is no such user, a KeyError will be raised unless
         a default value was passed, in which case that value is returned.
-
         """
         filename = str(serialNum) + '.user'
         filename = os.path.join(self.userDir(), filename)
@@ -86,7 +83,6 @@ class UserManagerToFile(UserManager):
         """Return a list of all the serial numbers of users found on disk.
 
         Serial numbers are always integers.
-
         """
         return [int(os.path.basename(num[:-5]))
             for num in glob(os.path.join(self.userDir(), '*.user'))]
@@ -97,7 +93,7 @@ class UserManagerToFile(UserManager):
     def setUserClass(self, userClass):
         """Overridden to mix in UserMixIn to the class that is passed in."""
         MixIn(userClass, UserMixIn)
-        super(UserManagerToFile, self).setUserClass(userClass)
+        UserManager.setUserClass(self, userClass)
 
 
     ## UserManager concrete methods ##
@@ -108,10 +104,11 @@ class UserManagerToFile(UserManager):
         return result
 
     def addUser(self, user):
-        assert isinstance(user, User)
+        if not isinstance(user, User):
+            raise TypeError('%s is not a User object' % (user,))
         user.setSerialNum(self.nextSerialNum())
-        user.externalId() # set unique id
-        super(UserManagerToFile, self).addUser(user)
+        user.externalId()  # set unique id
+        UserManager.addUser(self, user)
         user.save()
 
     def userForSerialNum(self, serialNum, default=NoDefault):
