@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 
-import os, sys
+import os
+import sys
 
 webwarePath = '/usr/local/Webware'
 appWorkPath = '/usr/local/Webware'
