@@ -22,8 +22,10 @@
 #
 #------------------------------------------------------------------------
 
-import sys, socket
-import os, cgi
+import sys
+import socket
+import os
+import cgi
 try:
     from cStringIO import StringIO
 except ImportError:
@@ -35,21 +37,25 @@ __version__ = '1.0'
 LENGTHSIZE  = 9
 LENGTHFMT   = '%09d'
 
-#---------------------------------------------------------------------------
 # Exception objects
 
-ConnectError     = 'lrwp.ConnectError'
-ConnectionClosed = 'lrwp.ConnectionClosed'
-SocketError      = 'lrwp.SocketError'
+class ConnectError(IOError):
+    """LRWP Connect Error"""
+
+
+class ConnectionClosed(IOError):
+    """LRWP Connection Closed Error"""
+
+
+class SocketError(IOError):
+    """LRWP Socket Error"""
 
-#---------------------------------------------------------------------------
 
 class Request(object):
     """Request object.
 
     Encapsulates the request/response I/O objects and CGI-Environment.
     An instance of this class is returned.
-
     """
     def __init__(self, lrwp):
         self.inp = lrwp.inp
@@ -69,8 +75,6 @@ class Request(object):
             environ=self.env, keep_blank_values=1)
 
 
-#---------------------------------------------------------------------------
-
 class LRWP(object):
 
     def __init__(self, name, host, port, vhost='', filter='', useStdio=False):
@@ -86,7 +90,6 @@ class LRWP(object):
             filter  A space separated list of file extenstions that should
                     be directed to this handler in filter mode.
                     (Not yet supported.)
-
         """
         self.name = name
         self.host = host
@@ -99,18 +102,16 @@ class LRWP(object):
         self.inp = None
         self.out = None
 
-    #----------------------------------------
     def connect(self):
         """Connect with the web server.
 
         Establishes the connection to the web server, using the parameters
         given at construction.
-
         """
         try:
             self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
             self.sock.connect((self.host, self.port))
-            self.sock.send("%s\xFF%s\xFF%s"
+            self.sock.sendall("%s\xFF%s\xFF%s"
                 % (self.name, self.vhost, self.filter))
             buf = self.sock.recv(1024)
             if buf != 'OK':
@@ -118,27 +119,25 @@ class LRWP(object):
         except socket.error, val:
             raise SocketError(val)
 
-    #----------------------------------------
     def acceptRequest(self):
         """Accecpt a request from the web server.
 
         Wait for, and accept a new request from the web server. Reads the
         name=value pairs that comprise the CGI environment, followed by the
         post data, if any. Constructs and returns a Request object.
-
         """
         if self.out:
             self.finish()
         try:
             # get the length of the environment data
             data = self.recvBlock(LENGTHSIZE)
-            if not data: # server closed down
+            if not data:  # server closed down
                 raise ConnectionClosed
             length = int(data)
 
             # and then the environment data
             data = self.recvBlock(length)
-            if not data: # server closed down
+            if not data:  # server closed down
                 raise ConnectionClosed
             data = data.split('\000')
             self.env = {}
@@ -149,14 +148,14 @@ class LRWP(object):
 
             # now get the size of the POST data
             data = self.recvBlock(LENGTHSIZE)
-            if not data: # server closed down
+            if not data:  # server closed down
                 raise ConnectionClosed
             length = int(data)
 
             # and the POST data...
             if length:
                 data = self.recvBlock(length)
-                if not data: # server closed down
+                if not data:  # server closed down
                     raise ConnectionClosed
                 self.inp = StringIO(data)
             else:
@@ -175,14 +174,11 @@ class LRWP(object):
         except socket.error, val:
             raise SocketError(val)
 
-
-    #----------------------------------------
     def recvBlock(self, size):
         """Receive a block from the socket.
 
         Pull an exact number of bytes from the socket, taking into
         account the possibility of multiple packets...
-
         """
         numRead = 0
         data = []
@@ -192,17 +188,15 @@ class LRWP(object):
                 return ''
             data.append(buf)
             numRead += len(buf)
-
         return ''.join(data)
 
-    #----------------------------------------
     def finish(self):
         """Complete the request and send the output back to the web server."""
         doc = self.out.getvalue()
         size = LENGTHFMT % (len(doc),)
         try:
-            self.sock.send(size)
-            self.sock.send(doc)
+            self.sock.sendall(size)
+            self.sock.sendall(doc)
         except socket.error, val:
             raise SocketError(val)
 
@@ -213,7 +207,6 @@ class LRWP(object):
         self.inp = None
         self.out = None
 
-    #----------------------------------------
     def close(self):
         """Close the LRWP connection to the web server."""
         self.sock.close()
@@ -222,11 +215,9 @@ class LRWP(object):
         self.inp = None
         self.out = None
 
-#---------------------------------------------------------------------------
-
 
 def _test():
-    import os, time
+    import os
 
     eol = '\r\n'
     appname = 'testapp1'
@@ -246,7 +237,7 @@ def _test():
     lrwp.connect()
 
     count = 0
-    while count < 5: # exit after servicing 5 requests
+    while count < 5:  # exit after servicing 5 requests
         req = lrwp.acceptRequest()
 
         doc = ['<HTML><HEAD><TITLE>LRWP TestApp (%s)</TITLE></HEAD>\n'
@@ -274,6 +265,5 @@ def _test():
 
 
 if __name__ == '__main__':
-    # import pdb
-    # pdb.run('_test()')
+    # import pdb; pdb.run('_test()')
     _test()
