@@ -1,15 +1,17 @@
 """JSON-RPC servlet base class
 
 Written by Jean-Francois Pieronne
-
 """
 
 import traceback
 try:
-    import simplejson
-except ImportError:
-    print "ERROR: simplejson is not installed."
-    print "Get it from http://cheeseshop.python.org/pypi/simplejson"
+    import json
+except ImportError:  # Python < 2.6
+    try:
+        import simplejson as json
+    except ImportError:
+        print "ERROR: simplejson is not installed."
+        print "Get it from https://pypi.python.org/pypi/simplejson/"
 
 from MiscUtils import StringIO
 from HTTPContent import HTTPContent
@@ -25,20 +27,19 @@ class JSONRPCServlet(HTTPContent):
     are able to be called by an JSON-RPC-enabled web page. This is very similar
     in functionality to Webware's actions.
 
-    Some basic security measures against JavaScript hijacking are taken     by
+    Some basic security measures against JavaScript hijacking are taken by
     default which can be deactivated if you're not dealing with sensitive data.
     You can further increase security by adding shared secret mechanisms.
-
     """
 
     # Class level variables that can be overridden by servlet instances:
-    _debug = False # set to True if you want to see debugging output
+    _debug = False  # set to True if you want to see debugging output
     # The following variables control security precautions concerning
     # a vulnerability known as "JavaScript hijacking". See also:
     # http://www.fortifysoftware.com/servlet/downloads/public/JavaScript_Hijacking.pdf
     # http://ajaxian.com/archives/protecting-a-javascript-service
-    _allowGet = False # set to True if you want to allow GET requests
-    _allowEval = False # set to True to allow direct evaluation of the response
+    _allowGet = False  # set to True if you want to allow GET requests
+    _allowEval = False  # set to True to allow direct evaluation of response
 
     def __init__(self):
         HTTPContent.__init__(self)
@@ -62,11 +63,11 @@ class JSONRPCServlet(HTTPContent):
         return []
 
     def writeError(self, msg):
-        self.write(simplejson.dumps(
+        self.write(json.dumps(
             {'id': self._id, 'code': -1, 'error': msg}))
 
     def writeResult(self, data):
-        data = simplejson.dumps(
+        data = json.dumps(
             {'id': self._id, 'result': data})
         if not self._allowEval:
             data = ('throw new Error'
@@ -77,10 +78,9 @@ class JSONRPCServlet(HTTPContent):
         """Execute method with arguments on the server side.
 
         Returns Javascript function to be executed by the client immediately.
-
         """
         request = self.request()
-        data = simplejson.loads(request.rawInput().read())
+        data = json.loads(request.rawInput().read())
         self._id, call, params = data['id'], data['method'], data['params']
         if call == 'system.listMethods':
             self.writeResult(self.exposedMethods())
