@@ -9,7 +9,6 @@ parts of the URL with each step.
 
 This root parser is generally `ContextParser`, which is instantiated and set
 up by `Application` (accessible through `Application.rootURLParser`).
-
 """
 
 import os
@@ -30,6 +29,7 @@ _moduleNameRE = re.compile('[^a-zA-Z_]')
 
 _globalApplication = None
 
+
 def application():
     """Returns the global Application."""
     return _globalApplication
@@ -53,7 +53,6 @@ class URLParser(object):
     If you cannot find a servlet, or some other (somewhat) expected error
     occurs, you should raise an exception. HTTPNotFound probably being the
     most interesting.
-
     """
 
     def __init__(self):
@@ -63,7 +62,6 @@ class URLParser(object):
         """Returns a servlet for the transaction.
 
         This is the top-level entry point, below it `parse` is used.
-
         """
         return self.parse(trans, trans.request().urlPath())
 
@@ -81,7 +79,6 @@ class ContextParser(URLParser):
 
     There is generally only one ContextParser, which can be found as
     ``application.rootURLParser()``.
-
     """
 
 
@@ -95,7 +92,6 @@ class ContextParser(URLParser):
 
         In __init__ we take the ``Contexts`` setting from
         Application.config and parse it slightly.
-
         """
         URLParser.__init__(self)
         # Need to set this here because we need for initialization, during
@@ -108,13 +104,13 @@ class ContextParser(URLParser):
         # add all contexts except the default, which we save until the end
         contexts = app.setting('Contexts')
         defaultContext = ''
-        for name, dir in contexts.items():
-            dir = os.path.normpath(dir) # for Windows
+        for name, path in contexts.items():
+            path = os.path.normpath(path)  # for Windows
             if name == 'default':
-                defaultContext = dir
+                defaultContext = path
             else:
                 name = '/'.join(filter(lambda x: x, name.split('/')))
-                self.addContext(name, dir)
+                self.addContext(name, path)
         if not defaultContext:
             # If no default context has been specified, and there is a unique
             # context not built into Webware, use it as the default context.
@@ -132,13 +128,13 @@ class ContextParser(URLParser):
                 for defaultContext in ('Default', 'Examples', 'Docs'):
                     if defaultContext in contexts:
                         break
-                else: # if not available, refuse the tempatation to guess
+                else:  # if not available, refuse the temptation to guess
                     raise KeyError("No default context has been specified.")
         if defaultContext in self._contexts:
             self._defaultContext = defaultContext
         else:
-            for name, dir in self._contexts.items():
-                if defaultContext == dir:
+            for name, path in self._contexts.items():
+                if defaultContext == path:
                     self._defaultContext = name
                     break
             else:
@@ -156,7 +152,6 @@ class ContextParser(URLParser):
 
         Returns the name of the context that the default context refers to,
         or 'default' if the default context is unique.
-
         """
         contexts = self._contexts
         contextDirs = {}
@@ -176,27 +171,26 @@ class ContextParser(URLParser):
             # The default context has no other name
             return 'default'
 
-    def addContext(self, name, dir):
+    def addContext(self, name, path):
         """Add a context to the system.
 
         The context will be imported as a package, going by `name`,
-        from the given directory. The directory doesn't have to match
+        from the given directory path. The directory doesn't have to match
         the context name.
-
         """
         if name == 'default':
-            dest = self.resolveDefaultContext(name, dir)
+            dest = self.resolveDefaultContext(name, path)
             self._defaultContext = dest
             if dest != 'default':
                 # in this case default refers to an existing context, so
                 # there's not much to do
-                print 'Default context aliases to: %s' % (dest)
+                print 'Default context aliases to: %s' % (dest,)
                 return
 
         e = None
         try:
             importAsName = name
-            localDir, packageName = os.path.split(dir)
+            localDir, packageName = os.path.split(path)
             if importAsName in sys.modules:
                 mod = sys.modules[importAsName]
             else:
@@ -209,9 +203,11 @@ class ContextParser(URLParser):
                         e = 'Could not import package'
                     # Maybe this happened because it had been forgotten
                     # to add the __init__.py file. So we try to create one:
-                    if os.path.exists(dir):
-                        f = os.path.join(dir, '__init__.py')
-                        if not os.path.exists(f):
+                    if os.path.exists(path):
+                        f = os.path.join(path, '__init__.py')
+                        if (not os.path.exists(f)
+                                and not os.path.exists(f + 'c')
+                                and not os.path.exists(f + 'o')):
                             print ("Creating __init__.py file"
                                 " for context '%s'" % name)
                             try:
@@ -233,28 +229,28 @@ class ContextParser(URLParser):
             # when the context path does not exist
             pass
         if e:
-            print 'Error loading context: %s: %s: dir=%s' % (name, e, dir)
+            print 'Error loading context: %s: %s: dir=%s' % (name, e, path)
             return
 
         if hasattr(mod, 'contextInitialize'):
             # @@ gat 2003-07-23: switched back to old method
             # of passing application as first parameter
             # to contextInitialize for backward compatibility
-            result = mod.contextInitialize(application(),
-                os.path.normpath(os.path.join(os.getcwd(), dir)))
+            result = mod.contextInitialize(
+                application(),
+                os.path.normpath(os.path.join(os.getcwd(), path)))
             # @@: funny hack...?
             if result is not None and 'ContentLocation' in result:
-                dir = result['ContentLocation']
+                path = result['ContentLocation']
 
-        print 'Loading context: %s at %s' % (name, dir)
-        self._contexts[name] = dir
+        print 'Loading context: %s at %s' % (name, path)
+        self._contexts[name] = path
 
     def absContextPath(self, path):
         """Get absolute context path.
 
         Resolves relative paths, which are assumed to be relative to the
         Application's serverSidePath (the working directory).
-
         """
         if os.path.isabs(path):
             return path
@@ -272,7 +268,6 @@ class ContextParser(URLParser):
 
         The context name and file path are stored in the request (accessible
         through `Request.serverSidePath` and `Request.contextName`).
-
         """
         # This is a hack... should probably go in the Transaction class:
         trans._fileParserInitSeen = {}
@@ -329,7 +324,6 @@ class _FileParser(URLParser):
     function `initApp`, as class variables. They cannot be set when the module
     is loaded, because the Application is not yet set up, so `initApp` is
     called in `Application.__init__`.
-
     """
 
 
@@ -340,7 +334,6 @@ class _FileParser(URLParser):
 
         Each parsed directory has a FileParser instance associated with it
         (``self._path``).
-
         """
         URLParser.__init__(self)
         self._path = path
@@ -363,7 +356,6 @@ class _FileParser(URLParser):
         This uses `fileNamesForBaseName` to find files in its directory.
         That function has several functions to define what files are ignored,
         hidden, etc.  See its documentation for more information.
-
         """
         if debug:
             print "FP(%r) parses %r" % (self._path, requestPath)
@@ -448,7 +440,6 @@ class _FileParser(URLParser):
             extensions exist, only the .tmpl file will be returned.
         ExtensionCascadeOrder:
             A list of extensions, ordered by priority.
-
         """
         if '*' in baseName:
             return []
@@ -494,7 +485,6 @@ class _FileParser(URLParser):
         ExtensionsToServe:
             If set, only files with these extensions will be
             served.  Like FilesToServe, only doesn't use globs.
-
         """
         ext = os.path.splitext(filename)[1]
         if ext in self._toIgnore:
@@ -533,7 +523,6 @@ class _FileParser(URLParser):
         ``["Main", "index", "main", "Index"]``, which are searched in order.
         A file with any extension is allowed, so the index can be an HTML file,
         a PSP file, a Kid template, a Python servlet, etc.
-
         """
         req = trans.request()
         # If requestPath is empty, then we're missing the trailing slash:
@@ -650,7 +639,6 @@ class _FileParser(URLParser):
             Paths are relative to the current directory.  If you
             don't want the current directory to be a last resort,
             you can include '.' in the joins.
-
         """
         if self._initModule is None:
             self._initModule = self.initModule()
@@ -739,7 +727,6 @@ class URLParameterParser(URLParser):
     Or (slightly less efficient):
 
         from WebKit.URLParser import URLParameterParser as SubParser
-
     """
 
 
@@ -762,7 +749,6 @@ class URLParameterParser(URLParser):
         The `hook` is the FileParser object that originally called this --
         we just want to strip stuff out of the URL and then give it back to
         the FileParser instance, which can actually find the servlet.
-
         """
         parts = requestPath.split('/')
         result = []
@@ -785,7 +771,6 @@ class ServletFactoryManagerClass(object):
 
     See `addServletFactory` for adding new factories, and `servletForFile`
     for getting the factories back.
-
     """
 
 
@@ -813,7 +798,6 @@ class ServletFactoryManagerClass(object):
         ``['.ht']``).  The special extension ``.*`` will match any
         file if no other factory is found.  See `ServletFactory`
         for more information.
-
         """
 
         self._factories.append(factory)
@@ -838,7 +822,6 @@ class ServletFactoryManagerClass(object):
 
         Uses `factoryForFile` to find the factory, which
         creates the servlet.
-
         """
         factory = self.factoryForFile(path)
         return factory.servletForTransaction(trans)
@@ -857,7 +840,6 @@ def initApp(app):
 
     This needs to be called before any of the URLParser-derived classes
     are instantiated.
-
     """
     global _globalApplication
     _globalApplication = app
@@ -870,6 +852,7 @@ def initApp(app):
 
     initParser(app)
 
+
 def initParser(app):
     """Initialize the FileParser Class."""
     cls = _FileParser
