@@ -2,7 +2,7 @@
 # Webware for Python
 # See Docs/index.html
 
-__all__ = ['Cookie', 'HTMLForException', 'HTTPStatusCodes', 'HTMLTag', 'Funcs']
+__all__ = ['HTMLForException', 'HTTPStatusCodes', 'HTMLTag', 'Funcs']
 
 def InstallInWebKit(appServer):
-	pass
+    pass
