@@ -23,7 +23,7 @@ Options:
                           so you can place it outside of the WorkDir.
   -l, --library=...       Other dirs to be included in the search path.
                           You may specify this option multiple times.
-  -i, --cvsignore         This will add .cvsignore files to the WorkDir.
+  -i, --gitignore         This will add .gitignore files to the WorkDir.
   -u, --user=...          The name or uid of the user to own the WorkDir.
                           This option is supported under Unix only.
   -g, --group=...         The name or gid of the group to own the WorkDir.
@@ -34,10 +34,9 @@ WorkDir:
 """
 
 # FUTURE
-# * Add options to immediately import the new directory tree into a
-#   CVS or SVN repository. In the case of a CVS repository, the
-#   .cvsignore files should be created automatically, and in case
-#   of SVN, the corresponding svn propset commands should be issued.
+# * Add an option to immediately create a Git repository in the new directory
+#   and add all relevant files to the repository. The .gitignore file should
+#   be automatically created in this case, and maybe .gitattributes as well.
 # * MakeAppWorkDir.py should set the admin password like install.py does.
 #   At the same time, install.py should be able to do a "app-less" install,
 #   from which the admin can create appdirs using MakeAppWorkDir.py.
@@ -48,7 +47,12 @@ WorkDir:
 # * Contributed to Webware for Python by Robin Dunn
 # * Improved by Christoph Zwerschke
 
-import sys, os, stat, re, glob, shutil
+import sys
+import os
+import stat
+import re
+import glob
+import shutil
 
 
 class MakeAppWorkDir(object):
@@ -61,18 +65,16 @@ class MakeAppWorkDir(object):
 
     Existing files will not be overwritten, but access permissions
     will be changed accordingly in any case.
-
     """
 
     def __init__(self, webwareDir, workDir, verbose=True, osType=None,
             contextName='MyContext', contextDir='', libraryDirs=None,
-            cvsIgnore=False, uid=None, gid=None):
+            gitIgnore=False, uid=None, gid=None):
         """Initializer for MakeAppWorkDir.
 
         Pass in at least the Webware directory and the target working
         directory. If you pass None for contextName then the default
         context will be the the WebKit/Examples directory as usual.
-
         """
         self._webwareDir = webwareDir
         self._webKitDir = os.path.join(webwareDir, 'WebKit')
@@ -86,7 +88,7 @@ class MakeAppWorkDir(object):
             libraryDirs = []
         self._libraryDirs = libraryDirs
         self._osType = osType
-        self._cvsIgnore = cvsIgnore
+        self._gitIgnore = gitIgnore
         self._uid = uid
         self._gid = gid
 
@@ -94,7 +96,6 @@ class MakeAppWorkDir(object):
         """These are all the steps needed to make a new runtime directory.
 
         You can override the steps taken here with your own methods.
-
         """
         if os.path.exists(self._workDir):
             self.msg("The target directory already exists.")
@@ -108,8 +109,8 @@ class MakeAppWorkDir(object):
         self.makeLauncherScripts()
         if self._contextName is not None:
             self.makeDefaultContext()
-        if self._cvsIgnore:
-            self.addCvsIgnore()
+        if self._gitIgnore:
+            self.addGitIgnore()
         self.changeOwner()
         self.printCompleted()
 
@@ -118,22 +119,21 @@ class MakeAppWorkDir(object):
         self.msg("Creating the directory tree...")
         standardDirs = (
             '', 'Cache', 'Configs', 'ErrorMsgs', 'Logs', 'Sessions')
-        for dir in standardDirs:
-            dir = os.path.join(self._workDir, dir)
-            if os.path.exists(dir):
-                self.msg("\t%s already exists." % dir)
+        for path in standardDirs:
+            path = os.path.join(self._workDir, path)
+            if os.path.exists(path):
+                self.msg("\t%s already exists." % path)
             else:
-                os.mkdir(dir)
-                self.msg("\t%s" % dir)
-        for dir in self._libraryDirs:
-            dir = os.path.join(self._workDir, dir)
-            if os.path.exists(dir):
-                self.msg("\t%s already exists." % dir)
+                os.mkdir(path)
+                self.msg("\t%s" % path)
+        for path in self._libraryDirs:
+            path = os.path.join(self._workDir, path)
+            if os.path.exists(path):
+                self.msg("\t%s already exists." % path)
             else:
-                os.makedirs(dir)
-                open(os.path.join(dir, '__init__.py'), 'w').write('#\n')
-                self.msg("\t%s created." % dir)
-        self.msg()
+                os.makedirs(path)
+                open(os.path.join(path, '__init__.py'), 'w').write('#\n')
+                self.msg("\t%s created." % path)
 
     def copyConfigFiles(self):
         """Make a copy of the config files in the Configs directory."""
@@ -141,16 +141,16 @@ class MakeAppWorkDir(object):
         configs = glob.glob(os.path.join(self._webKitDir,
             'Configs', '*.config'))
         for name in configs:
-            newname = os.path.join(self._workDir, "Configs",
+            newName = os.path.join(self._workDir, "Configs",
                 os.path.basename(name))
-            if os.path.exists(newname):
-                self.msg("\t%s already exists." % newname)
+            if os.path.exists(newName):
+                self.msg("\t%s already exists." % newName)
             else:
-                self.msg("\t%s" % newname)
-                shutil.copyfile(name, newname)
-            mode = os.stat(newname)[stat.ST_MODE]
+                self.msg("\t%s" % newName)
+                shutil.copyfile(name, newName)
+            mode = os.stat(newName)[stat.ST_MODE]
             # remove public read/write/exec perms
-            os.chmod(newname, mode & 0770)
+            os.chmod(newName, mode & 0770)
         self.msg()
 
     def copyOtherFiles(self):
@@ -168,20 +168,20 @@ class MakeAppWorkDir(object):
                 chmod = True
             else:
                 chmod = False
-            newname = os.path.join(self._workDir, os.path.basename(name))
-            if os.path.exists(newname):
-                self.msg("\t%s already exists." % newname)
+            newName = os.path.join(self._workDir, os.path.basename(name))
+            if os.path.exists(newName):
+                self.msg("\t%s already exists." % newName)
                 if chmod:
-                    os.chmod(newname, 0755)
+                    os.chmod(newName, 0755)
             else:
-                oldname = os.path.join(self._webKitDir, name)
-                if os.path.exists(oldname):
-                    self.msg("\t%s" % newname)
-                    shutil.copyfile(oldname, newname)
+                oldName = os.path.join(self._webKitDir, name)
+                if os.path.exists(oldName):
+                    self.msg("\t%s" % newName)
+                    shutil.copyfile(oldName, newName)
                     if chmod:
-                        os.chmod(newname, 0755)
+                        os.chmod(newName, 0755)
                 else:
-                    self.msg("\tWarning: Cannot find %r." % oldname)
+                    self.msg("\tWarning: Cannot find %r." % oldName)
         self.msg()
 
     def makeLauncherScripts(self):
@@ -206,29 +206,29 @@ class MakeAppWorkDir(object):
         for name in launcherScripts:
             if name.endswith('Service.py') and self._osType != 'nt':
                 continue
-            newname = os.path.join(workDir, name)
-            if os.path.exists(newname):
-                self.msg("\t%s already exists." % newname)
-                os.chmod(newname, 0755)
+            newName = os.path.join(workDir, name)
+            if os.path.exists(newName):
+                self.msg("\t%s already exists." % newName)
+                os.chmod(newName, 0755)
             else:
-                oldname = os.path.join(webKitDir, name)
-                if os.path.exists(oldname):
-                    self.msg("\t%s" % newname)
+                oldName = os.path.join(webKitDir, name)
+                if os.path.exists(oldName):
+                    self.msg("\t%s" % newName)
                     script = launcherScripts[name] % locals()
-                    open(newname, "w").write(script)
-                    os.chmod(newname, 0755)
+                    open(newName, "w").write(script)
+                    os.chmod(newName, 0755)
                 else:
-                    self.msg("\tWarning: Cannot find %r." % oldname)
+                    self.msg("\tWarning: Cannot find %r." % oldName)
         name = 'WebKit.cgi'
-        newname = os.path.join(workDir, os.path.basename(name))
-        if os.path.exists(newname):
-            self.msg("\t%s already exists." % newname)
-            os.chmod(newname, 0755)
+        newName = os.path.join(workDir, os.path.basename(name))
+        if os.path.exists(newName):
+            self.msg("\t%s already exists." % newName)
+            os.chmod(newName, 0755)
         else:
-            oldname = os.path.join(webKitDir, os.path.join('Adapters', name))
-            if os.path.exists(oldname):
-                self.msg("\t%s" % newname)
-                script = open(oldname, 'r').read()
+            oldName = os.path.join(webKitDir, os.path.join('Adapters', name))
+            if os.path.exists(oldName):
+                self.msg("\t%s" % newName)
+                script = open(oldName, 'r').read()
                 script = re.sub('^#!/usr/bin/env python\n',
                     '#!%s\n' % executable, script, 1)
                 parameter = (('workDir', workDir), ('webwareDir', webwareDir))
@@ -238,10 +238,10 @@ class MakeAppWorkDir(object):
                     if n != 1:
                         self.msg("\tWarning: %s cannot be set in %s."
                             % (p[0], name))
-                open(newname, 'w').write(script)
-                os.chmod(newname, 0755)
+                open(newName, 'w').write(script)
+                os.chmod(newName, 0755)
             else:
-                self.msg("\tWarning: Cannot find %r." % oldname)
+                self.msg("\tWarning: Cannot find %r." % oldName)
         self.msg()
 
     def makeDefaultContext(self):
@@ -291,29 +291,30 @@ class MakeAppWorkDir(object):
             self.msg("\tWarning: Default context could not be set.")
         self.msg()
 
-    def addCvsIgnore(self):
-        self.msg("Creating .cvsignore files...")
-        files = {
-            '.': '*.pyc\n*.pyo\n'
-                'address.*\nhttpd.*\nappserverpid.*\nprofile.pstats',
-            'Cache': '[a-zA-Z0-9]*',
-            'ErrorMsgs': '[a-zA-Z0-9]*',
-            'Logs': '[a-zA-Z0-9]*',
-            'Sessions': '[a-zA-Z0-9]*',
-            self._contextName: '*.pyc\n*.pyo'
-        }
-        foundFiles = False
-        for dir, contents in files.items():
-            filename = os.path.join(self._workDir,
-                dir, '.cvsignore')
+    def addGitIgnore(self):
+        self.msg("Creating .gitignore files...")
+        existed = False
+        ignore = ('*~ *.address *.bak *.default *.log *.patch *.pid'
+            '*.pstats *.pyc *.pyo *.ses *.swp')
+        ignore = '\n'.join(ignore.split()) + '\n'
+        filename = os.path.join(self._workDir, '.gitignore')
+        if os.path.exists(filename):
+            existed = True
+        else:
+            f = open(filename, 'w')
+            f.write(ignore)
+            f.close()
+        ignore = '!.gitignore\n'
+        for subDir in 'Cache ErrorMsgs Logs Sessions'.split():
+            filename = os.path.join(self._workDir, subDir, '.gitignore')
             if os.path.exists(filename):
-                foundFiles = True
+                existed = True
             else:
                 f = open(filename, 'w')
-                f.write(contents)
+                f.write(ignore)
                 f.close()
-        if foundFiles:
-            self.msg("\tDid not change existing .cvsignore files.")
+        if existed:
+            self.msg("\tDid not change existing .gitignore file.")
         self.msg()
 
     def changeOwner(self):
@@ -354,7 +355,7 @@ http://localhost:8080
 
 In a productive environment, you will probably want to use Apache or another
 web server instead of the built-in HTTP server. The most simple (but least
-performant) solution to do this is by using the Python WebKit.cgi CGI script.
+efficient) solution to do this is by using the Python WebKit.cgi CGI script.
 Copy it to your web server's cgi-bin directory or anywhere else that it will
 execute CGIs from. If you see import errors, you may need to modify the file
 permissions on your Webware directory so that the CGI script can access it.
@@ -369,7 +370,8 @@ Have fun!
             else:
                 print
 
-launcherScripts = { # launcher scripts with adjusted parameters
+
+launcherScripts = {  # launcher scripts with adjusted parameters
 
 'Launch.py': r"""#!%(executable)s
 
@@ -422,7 +424,8 @@ serviceDescription = ("This is the threaded application server"
     " of the Webware for Python web framework.")
 serviceDeps = []
 
-import sys, os
+import sys
+import os
 sys.path.insert(0, webwareDir)
 
 from WebKit import AppServerService as service
@@ -445,9 +448,10 @@ if __name__ == '__main__':
     service.main()
 """
 
-} # end of launcher scripts
+}  # end of launcher scripts
 
-exampleContext = { # files copied to example context
+
+exampleContext = {  # files copied to example context
 
 # This is used to create a very simple sample context for the new
 # work dir to give the newbie something easy to play with.
@@ -489,25 +493,27 @@ class Main(Page):
         self.writeln('</ul>')
 """
 
-} # end of example context files
+}  # end of example context files
+
 
 def usage():
     """Print the docstring and exit with error."""
     print __doc__
     sys.exit(2)
 
+
 def main(args=None):
     """Evaluate the command line arguments and call MakeAppWorkDir."""
     if args is None:
         args = sys.argv[1:]
-    contextName = contextDir = cvsIgnore = user = group = None
+    contextName = contextDir = gitIgnore = user = group = None
     libraryDirs = []
     # Get all options:
     from getopt import getopt, GetoptError
     try:
         opts, args = getopt(args, 'c:d:l:iu:g:', [
             'context-name=', 'context-dir=', 'library=',
-            'cvsignore', 'user=', 'group='])
+            'gitignore', 'user=', 'group='])
     except GetoptError, error:
         print str(error)
         usage()
@@ -518,8 +524,8 @@ def main(args=None):
             contextDir = arg
         elif opt in ('-l', '--library'):
             libraryDirs.append(arg)
-        elif opt in ('-i', '--cvsignore'):
-            cvsIgnore = True
+        elif opt in ('-i', '--gitignore'):
+            gitIgnore = True
         elif opt in ('-u', '--user'):
             user = arg
         elif opt in ('-g', '--group'):
@@ -529,7 +535,7 @@ def main(args=None):
         workDir = args.pop(0)
     except IndexError:
         usage()
-    if args:# too many parameters
+    if args:  # too many parameters
         usage()
     if not contextName:
         if contextDir:
@@ -577,8 +583,9 @@ def main(args=None):
     binDir = os.path.dirname(os.path.abspath(scriptName))
     webwareDir = os.path.abspath(os.path.join(binDir, os.pardir))
     mawd = MakeAppWorkDir(webwareDir, workDir, True, None,
-        contextName, contextDir, libraryDirs, cvsIgnore, uid, gid)
-    mawd.buildWorkDir() # go!
+        contextName, contextDir, libraryDirs, gitIgnore, uid, gid)
+    mawd.buildWorkDir()  # go!
+
 
 if __name__ == '__main__':
     main()
